@@ -1,3 +1,5 @@
+import warnings
+
 import numpy as np
 
 from ..core import indexing
@@ -45,7 +47,7 @@ class PydapArrayWrapper(BackendArray):
         result = robust_getitem(array, key, catch=ValueError)
         # in some cases, pydap doesn't squeeze axes automatically like numpy
         axis = tuple(n for n, k in enumerate(key) if isinstance(k, integer_types))
-        if result.ndim + len(axis) != array.ndim and len(axis) > 0:
+        if result.ndim + len(axis) != array.ndim and axis:
             result = np.squeeze(result, axis)
 
         return result
@@ -92,7 +94,7 @@ class PydapDataStore(AbstractDataStore):
         return cls(ds)
 
     def open_store_variable(self, var):
-        data = indexing.LazilyOuterIndexedArray(PydapArrayWrapper(var))
+        data = indexing.LazilyIndexedArray(PydapArrayWrapper(var))
         return Variable(var.dimensions, data, _fix_attributes(var.attributes))
 
     def get_variables(self):
@@ -108,8 +110,10 @@ class PydapDataStore(AbstractDataStore):
 
 
 class PydapBackendEntrypoint(BackendEntrypoint):
-    def guess_can_open(self, store_spec):
-        return isinstance(store_spec, str) and is_remote_uri(store_spec)
+    available = has_pydap
+
+    def guess_can_open(self, filename_or_obj):
+        return isinstance(filename_or_obj, str) and is_remote_uri(filename_or_obj)
 
     def open_dataset(
         self,
@@ -122,7 +126,16 @@ class PydapBackendEntrypoint(BackendEntrypoint):
         use_cftime=None,
         decode_timedelta=None,
         session=None,
+        lock=None,
     ):
+        # TODO remove after v0.19
+        if lock is not None:
+            warnings.warn(
+                "The kwarg 'lock' has been deprecated for this backend, and is now "
+                "ignored. In the future passing lock will raise an error.",
+                DeprecationWarning,
+            )
+
         store = PydapDataStore.open(
             filename_or_obj,
             session=session,
@@ -143,5 +156,4 @@ class PydapBackendEntrypoint(BackendEntrypoint):
             return ds
 
 
-if has_pydap:
-    BACKEND_ENTRYPOINTS["pydap"] = PydapBackendEntrypoint
+BACKEND_ENTRYPOINTS["pydap"] = PydapBackendEntrypoint
